@@ -12,11 +12,11 @@ Getopt::Chain - Command-line processing like svn and git
 
 =head1 VERSION
 
-Version 0.013
+Version 0.014
 
 =cut
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 =head1 SYNPOSIS 
 
@@ -128,9 +128,15 @@ use Getopt::Chain::Context;
 
 has builder => qw/is ro lazy_build 1/, handles => [qw/ dispatcher /];
 sub _build_builder {
+    require Getopt::Chain::Builder;
     return Getopt::Chain::Builder->new;
 }
 
+has context_from => qw/is ro isa Str|CodeRef lazy_build 1/;
+sub _build_context_from {
+    return 'Getopt::Chain::Context';
+}
+
 sub process {
     if (! ref $_[0] && $_[0] && $_[0] eq 'Getopt::Chain') {
         shift;
@@ -149,11 +155,23 @@ sub run {
 
     $arguments = [ @ARGV ] unless $arguments;
 
-    my $context = Getopt::Chain::Context->new( dispatcher => $self->dispatcher, arguments => $arguments );
+    my $context = $self->new_context( dispatcher => $self->dispatcher, arguments => $arguments );
     $context->run;
     return $context->options;
 }
 
+sub new_context {
+    my $self = shift;
+
+    my $context_from = $self->context_from;
+    if (! ref $context_from) {
+        return $context_from->new( @_ );
+    }
+    else {
+        croak "Don't understand context source \"$context_from\"";
+    }
+}
+
 use MooseX::MakeImmutable;
 MooseX::MakeImmutable->lock_down;
 
