@@ -151,7 +151,14 @@ sub consume_arguments($$) { # Will modify arguments, reflecting consumption
     croak "There was an error option-processing arguments: $@" if $@;
 
     if (@$arguments && is_option_like $arguments->[0]) {
-        croak "Have remainder arguments after option-processing: ", $arguments->[0];
+        if (0) {
+            croak "Have remainder arguments after option-processing: ", $arguments->[0];
+        }
+        else {
+            my @discard;
+            push @discard, shift @$arguments while $arguments->[0] && is_option_like $arguments->[0];
+            warn "Unknown option-like argument@{[ @discard == 1 ? '' : 's' ]} (discarding): @discard", "\n";
+        }
     }
 
     return ( \%options );
@@ -165,7 +172,14 @@ sub _build__options {
     return Hash::Param->new(params => {});
 }
 
-has stash => qw/is ro isa HashRef/, default => sub { {} };
+has _stash => qw/is ro isa HashRef/, default => sub { {} };
+sub stash {
+    my $self = shift;
+    return $self->_stash unless @_;
+    my $stash = $self->_stash;
+    while ( @_ ) { my ($k, $v) = (shift @_, shift @_); $stash->{$k} = $v }
+    return $stash;
+}
 
 # The original arguments from the commandline (or wherever)... read only!
 has arguments => qw/metaclass Collection::Array reader _arguments required 1 lazy 1 isa ArrayRef/, default => sub { [] }, provides => {qw/
@@ -234,18 +248,27 @@ sub next_path_part {
     my $self = shift;
 
     return unless defined (my $argument = $self->first_remaining_argument);
-    croak "Had remainder arguments after option-processing: ", $argument, " @ ", $self->path_as_string, " [", join ' ', $self->remaining_arguments, "]" if is_option_like $argument;
+    if (0) {
+        croak "Had remainder arguments after option-processing: ", $argument, " @ ", $self->path_as_string, " [", join ' ', $self->remaining_arguments, "]" if is_option_like $argument;
+    }
+    else {
+        while ( defined $argument && is_option_like $argument ) {
+            warn "Discarding option-like argument: ", $argument, "\n";
+            $self->shift_remaining_argument;
+            return unless defined ($argument = $self->first_remaining_argument);
+        }
+    }
     return $self->shift_remaining_argument; # Same as $argument, really
 }
 
-sub at_end {
+sub last {
     my $self = shift;
     return ! defined $self->first_remaining_argument;
 }
 
 sub path_as_string {
     my $self = shift;
-    return join '/', '^START', $self->path, ($self->at_end ? '$' : ());
+    return join '/', '^START', $self->path, ($self->last ? '$' : ());
 }
 
 sub run_step { # Called from within the Path::Dispatcher rule
@@ -332,6 +355,11 @@ sub run {
     my $self = shift;
     my $control = shift;
 
+    my @arguments;
+    if ($control->{arguments_from_1} && defined $1) {
+        push @arguments, grep { length } split m/\s+/, $1;
+    }
+
     my $options = {};
     my $arguments = [ $self->arguments ];
     my $argument_schema = [ $self->argument_schema ];
@@ -355,13 +383,15 @@ sub run {
 
     my $last = ! @$arguments;
 
-    unless ($last) {
+    unless ($last || $control->{always_run}) {
         warn "Context::Step::run ", $self->context->path_as_string, " SKIP\n" if DEBUG;
         return;
     }
 
+    push @arguments, @$arguments; # TODO: Test this
+
     my $run = $self->_run;
-    $run->( $self->context, @$arguments ) if $run;
+    $run->( $self->context, @arguments ) if $run;
 
     return 1;
 }
